@@ -44,6 +44,7 @@
 #include "sshmasterconnection.h"
 
 
+
 #ifdef Q_OS_WIN
 #include <windows.h>
 #endif
@@ -165,6 +166,7 @@ struct ConfigFile
     bool brokerAuthenticated;
     bool brokerNoAuth;
     bool brokerAutologin;
+    bool brokerAutologoff;
     QString brokerSshKey;
     QString iniFile;
     QString server;
@@ -196,6 +198,7 @@ struct ConfigFile
     //
     bool useSnd;
     bool useFs;
+    bool published;
     int conSpeed;
     QString compMet;
     int imageQ;
@@ -324,6 +327,9 @@ public:
         ARTS,
         ESD
     };
+
+    static bool debugging;
+
     static bool portable;
     ONMainWindow ( QWidget *parent = 0 );
     ~ONMainWindow();
@@ -521,6 +527,7 @@ public:
     }
 #endif
 
+
 private:
     QString m_x2goconfig;
     QStringList _internApplicationsNames;
@@ -673,6 +680,7 @@ private:
     QAction *act_abclient;
     QAction *act_support;
     QAction *act_shareFolder;
+    QAction *act_showApps;
     QAction *act_suspend;
     QAction *act_terminate;
     QAction *act_reconnect;
@@ -891,6 +899,7 @@ private:
     void removeAppsFromTray();
     void plugAppsInTray();
     QMenu* initTrayAppMenu(QString text, QPixmap icon);
+    void setTrayIconToSessionIcon(QString info);
 
 
 protected:
