@@ -344,6 +344,7 @@ void SessionButton::redraw()
     cmdBox->addItem ( "GNOME" );
     cmdBox->addItem ( "LXDE" );
     cmdBox->addItem ( "XFCE" );
+    cmdBox->addItem ( "MATE" );
     cmdBox->addItem ( "UNITY" );
     cmdBox->addItem ( tr ( "RDP connection" ) );
     cmdBox->addItem ( tr ( "XDMCP" ) );
@@ -374,6 +375,11 @@ void SessionButton::redraw()
         cmdpix.load ( par->iconsPath ( "/16x16/xfce.png" ) );
         cmdBox->setCurrentIndex ( XFCE );
     }
+    else if ( command == "MATE" )
+    {
+        cmdpix.load ( par->iconsPath ( "/16x16/mate.png" ) );
+        cmdBox->setCurrentIndex ( MATE );
+    }
     else if ( command =="LXDE" )
     {
         cmdpix.load ( par->iconsPath ( "/16x16/lxde.png" ) );
@@ -433,8 +439,15 @@ void SessionButton::redraw()
         for (uint i=0;i<displays;++i)
         {
             geomBox->addItem ( tr( "Display " )+QString::number(i+1));
+
+            //add maximun available area
+            geomBox->addItem( QString::number(QApplication::desktop()->availableGeometry(i).width()) + "x" + QString::number(QApplication::desktop()->availableGeometry(i).height()));
+
+
         }
 #ifndef Q_WS_HILDON
+
+
     geomBox->addItem ( "1440x900" );
     geomBox->addItem ( "1280x1024" );
     geomBox->addItem ( "1024x768" );
@@ -675,6 +688,11 @@ void SessionButton::slot_cmd_change ( const QString& command )
         newRootless=false;
         pix.load ( par->iconsPath ( "/16x16/xfce.png" ) );
     }
+    else if ( command == "MATE" )
+    {
+        newRootless=false;
+        pix.load ( par->iconsPath ( "/16x16/mate.png" ) );
+    }
     else if ( command ==tr ( "Connection to local desktop" ) )
     {
         newRootless=false;
@@ -723,6 +741,11 @@ void SessionButton::slot_cmd_change ( const QString& command )
         cmd="XFCE";
         newRootless=false;
     }
+    if ( command=="mate-session" )
+    {
+        cmd="MATE";
+        newRootless=false;
+    }
     if (command== tr("Published applications"))
     {
         published=true;
