@@ -1,23 +1,19 @@
-
-/***************************************************************************
- *   Copyright (C) 2005-2012 by Oleksandr Shneyder   *
- *   oleksandr.shneyder@obviously-nice.de   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+/**************************************************************************
+*   Copyright (C) 2005-2012 by Oleksandr Shneyder                         *
+*   o.shneyder@phoca-gmbh.de                                              *
+*                                                                         *
+*   This program is free software; you can redistribute it and/or modify  *
+*   it under the terms of the GNU General Public License as published by  *
+*   the Free Software Foundation; either version 2 of the License, or     *
+*   (at your option) any later version.                                   *
+*   This program is distributed in the hope that it will be useful,       *
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+*   GNU General Public License for more details.                          *
+*                                                                         *
+*   You should have received a copy of the GNU General Public License     *
+*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+***************************************************************************/
 
 #include "x2goclientconfig.h"
 #include "x2gologdebug.h"
@@ -33,7 +29,8 @@
 #undef DEBUG
 // #define DEBUG
 
-SshProcess::SshProcess(SshMasterConnection* master, QObject* parent): QObject(parent)
+
+SshProcess::SshProcess(SshMasterConnection* master, int pid): QObject(0)
 {
     masterCon=master;
     serverSocket=0;
@@ -41,6 +38,7 @@ SshProcess::SshProcess(SshMasterConnection* master, QObject* parent): QObject(pa
     connect(master,SIGNAL(ioErr(SshProcess*,QString,QString)),this,SLOT(slotIOerr(SshProcess*,QString,QString)));
     tunnel=false;
     normalExited=true;
+    this->pid=pid;
 }
 
 SshProcess::~SshProcess()
@@ -96,7 +94,7 @@ void SshProcess::tunnelLoop()
     {
         QString err=tr("Error creating socket");
         x2goDebug<<err<<endl;
-        emit sshFinished(false,err,this);
+        emit sshFinished(false,err,pid);
         return;
     }
 #ifndef Q_OS_WIN
@@ -114,15 +112,15 @@ void SshProcess::tunnelLoop()
     {
         QString err=tr("Error binding ")+localHost+":"+QString::number(localPort);
         x2goDebug<<err<<endl;
-        emit sshFinished(false,err,this);
+        emit sshFinished(false,err,pid);
         return;
     }
     listen(serverSocket,5);
     addrlen=sizeof(struct sockaddr_in);
     QTimer* timer=new QTimer();
     connect(timer,SIGNAL(timeout()),this,SLOT(slotCheckNewConnection()));
-    timer->start(500);
-    emit sshTunnelOk();
+    timer->start(100);
+    emit sshTunnelOk(pid);
 #ifdef DEBUG
     x2goDebug<<"Direct tunnel: waiting for connections on "<<localHost<<":"<<localPort<<endl;
 #endif
@@ -130,7 +128,12 @@ void SshProcess::tunnelLoop()
 
 void SshProcess::startNormal(const QString& cmd)
 {
-    masterCon->addChannelConnection(this, cmd);
+    QString shcmd = "sh -c \""+cmd+"\"";
+// #ifdef DEBUG
+// ONLY UNCOMMENT FOR TESTING, MIGHT REVEAL PASSWORD WHEN command=RDP
+//    x2goDebug<<"executing remote command: "<<shcmd<<endl;
+// #endif
+    masterCon->addChannelConnection(this, shcmd);
     connect(masterCon,SIGNAL(stdOut(SshProcess*,QByteArray)),this,SLOT(slotStdOut(SshProcess*,QByteArray)));
     connect(masterCon,SIGNAL(channelClosed(SshProcess*)), this,SLOT(slotChannelClosed(SshProcess*)));
 }
@@ -196,20 +199,20 @@ void SshProcess::slotCopyErr(SshProcess* creator, QString message, QString sshSe
 {
     if (creator!=this)
         return;
-    emit sshFinished(false, message+" - "+sshSessionErr, this);
+    emit sshFinished(false, message+" - "+sshSessionErr, pid);
 }
 
 void SshProcess::slotCopyOk(SshProcess* creator)
 {
     if (creator!=this)
         return;
-    emit sshFinished(true,"", this);
+    emit sshFinished(true,"", pid);
 }
 
 void SshProcess::slotReverseTunnelOk(SshProcess* creator)
 {
     if (creator==this)
-        emit sshTunnelOk();
+        emit sshTunnelOk(pid);
 }
 
 
@@ -238,5 +241,5 @@ void SshProcess::slotChannelClosed(SshProcess* creator)
 #ifdef DEBUG
     x2goDebug<<"ssh finished:"<<normalExited<<" - "<<output<<endl;
 #endif
-    emit sshFinished(normalExited, output, this);
+    emit sshFinished(normalExited, output, pid);
 }
